# AminoLab
AminoLab Api For AminoApps using aminoapps.com/api
github link >> https://github.com/LilZevi/AminoLab
### Example
```python3
#Login
import AminoLab
client = AminoLab.Client()
email = input("Email >> ")
password = input("Password >> ")
client.auth(email=email, password=password)
```
P.S - More Examples in https://github.com/LilZevi/AminoLab/blob/main/src/examples.py